/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import type { SequenceId } from "./editManagerFormat.js";
/**
 * Compares two sequenceIds. Returns a negative number if a \< b, a positive number if a \> b, and 0 if a === b.
 * Note that this handles cases where indexInBatch is Number.POSITIVE_INFINITY.
 */
export declare const sequenceIdComparator: (a: SequenceId, b: SequenceId) => number;
export declare const equalSequenceIds: (a: SequenceId, b: SequenceId) => boolean;
export declare const minSequenceId: (a: SequenceId, b: SequenceId) => SequenceId;
export declare const maxSequenceId: (a: SequenceId, b: SequenceId) => SequenceId;
/**
 * Returns the upper bound (maximum possible) sequenceId that can occur just before the given sequenceId.
 * Some examples:
 * 1. sequenceId = \{ sequenceNumber: 1, indexInBatch: 2 \}. The upper bound is \{ sequenceNumber: 1, indexInBatch: 1 \}.
 * 2. sequenceId = \{ sequenceNumber: 2 \}. The upper bound is \{ sequenceNumber: 1, indexInBatch: Number.POSITIVE_INFINITY \}.
 * The indexInBatch value of the previous commit will depend on how many ops were in the previous batch of messages received.
 */
export declare const getUpperBoundOfPreviousSequenceId: (sequenceId: SequenceId) => SequenceId;
//# sourceMappingURL=sequenceIdUtils.d.ts.map